@@ -7,23 +7,27 @@
 
 from __future__ import annotations
 
-from ._version import __version__
+from pikepdf._version import __version__
 
 try:
-    from . import _core
+    from pikepdf import _core
 except ImportError as _e:  # pragma: no cover
     _msg = "pikepdf's extension library failed to import"
     raise ImportError(_msg) from _e
 
-from ._core import (
+from pikepdf._core import (
     AccessMode,
+    AcroForm,
+    AcroFormField,
     Annotation,
+    AnnotationFlag,
     AttachedFileSpec,
     ContentStreamInlineImage,
     ContentStreamInstruction,
     DataDecodingError,
     DeletedObjectError,
     ForeignObjectError,
+    FormFieldFlag,
     Job,
     JobUsageError,
     Matrix,
@@ -41,8 +45,12 @@ from ._core import (
     TokenFilter,
     TokenType,
 )
-from ._exceptions import DependencyError
-from .objects import (
+from pikepdf.exceptions import (
+    DependencyError,
+    OutlineStructureError,
+    UnsupportedImageTypeError,
+)
+from pikepdf.objects import (
     Array,
     Dictionary,
     Name,
@@ -52,29 +60,32 @@ from .objects import (
     Stream,
     String,
 )
-from .models import (
+from pikepdf.models import (
     Encryption,
     Outline,
     OutlineItem,
-    OutlineStructureError,
     PageLocation,
     PdfImage,
     PdfInlineImage,
-    PdfMatrix,
     Permissions,
-    UnsupportedImageTypeError,
     make_page_destination,
     parse_content_stream,
     unparse_content_stream,
 )
 
+from pikepdf.models.ctm import (
+    get_objects_with_ctm,
+)
+
+
 # Importing these will monkeypatch classes defined in C++ and register a new
 # pdfdoc codec
 # While _cpphelpers is intended to be called from our C++ code only, explicitly
 # importing helps introspection tools like PyInstaller figure out that the module
 # is necessary.
-from . import _cpphelpers, _methods, codec  # noqa: F401, F841
-from . import settings
+from pikepdf import _cpphelpers, _methods, codec  # noqa: F401, F841
+from pikepdf import settings
+from pikepdf import exceptions
 
 __libqpdf_version__: str = _core.qpdf_version()
 
@@ -89,54 +100,61 @@ new = Pdf.new
 _exclude_from__all__ = {'open', 'new', 'codec', 'objects', 'jbig2'}
 
 __all__ = [
+    '__libqpdf_version__',
+    '__version__',
     'AccessMode',
+    'AcroForm',
+    'AcroFormField',
     'Annotation',
+    'AnnotationFlag',
+    'Array',
     'AttachedFileSpec',
     'ContentStreamInlineImage',
     'ContentStreamInstruction',
     'DataDecodingError',
     'DeletedObjectError',
     'DependencyError',
+    'Dictionary',
+    'Encryption',
+    'exceptions',
     'ForeignObjectError',
+    'FormFieldFlag',
+    'get_objects_with_ctm',
+    'HifiPrintImageNotTranscodableError',
+    'InvalidPdfImageError',
     'Job',
     'JobUsageError',
+    'make_page_destination',
     'Matrix',
+    'models',
+    'Name',
     'NameTree',
     'NumberTree',
+    'Object',
     'ObjectHelper',
     'ObjectStreamMode',
-    'Page',
-    'PasswordError',
-    'Pdf',
-    'PdfError',
-    'Rectangle',
-    'StreamDecodeLevel',
-    'Token',
-    'TokenFilter',
-    'TokenType',
-    'Array',
-    'Dictionary',
-    'Name',
-    'Object',
     'ObjectType',
     'Operator',
-    'Stream',
-    'String',
-    'models',
-    'Encryption',
     'Outline',
     'OutlineItem',
     'OutlineStructureError',
+    'Page',
     'PageLocation',
+    'parse_content_stream',
+    'PasswordError',
+    'Pdf',
+    'PdfError',
     'PdfImage',
     'PdfInlineImage',
-    'PdfMatrix',
     'Permissions',
-    'UnsupportedImageTypeError',
-    'make_page_destination',
-    'parse_content_stream',
-    'unparse_content_stream',
+    'Rectangle',
     'settings',
-    '__libqpdf_version__',
-    '__version__',
+    'Stream',
+    'StreamDecodeLevel',
+    'String',
+    'Token',
+    'TokenFilter',
+    'TokenType',
+    'unparse_content_stream',
+    'UnsupportedImageTypeError',
 ]
