@@ -5,7 +5,6 @@
 
 from __future__ import annotations
 
-import sys
 from abc import ABC, abstractmethod
 from copy import copy
 from decimal import Decimal
@@ -22,6 +21,7 @@ from pikepdf import jbig2
 from pikepdf._core import Buffer, Pdf, PdfError, StreamDecodeLevel
 from pikepdf._exceptions import DependencyError
 from pikepdf.models import _transcoding
+from pikepdf.models._transcoding import ImageDecompressionError
 from pikepdf.objects import (
     Array,
     Dictionary,
@@ -33,16 +33,10 @@ from pikepdf.objects import (
 
 T = TypeVar('T')
 
-if sys.version_info >= (3, 9):
-    RGBDecodeArray = tuple[float, float, float, float, float, float]
-    GrayDecodeArray = tuple[float, float]
-    CMYKDecodeArray = tuple[float, float, float, float, float, float, float, float]
-    DecodeArray = Union[RGBDecodeArray, GrayDecodeArray, CMYKDecodeArray]
-else:
-    RGBDecodeArray = Any
-    GrayDecodeArray = Any
-    CMYKDecodeArray = Any
-    DecodeArray = Any
+RGBDecodeArray = tuple[float, float, float, float, float, float]
+GrayDecodeArray = tuple[float, float]
+CMYKDecodeArray = tuple[float, float, float, float, float, float, float, float]
+DecodeArray = Union[RGBDecodeArray, GrayDecodeArray, CMYKDecodeArray]
 
 
 class UnsupportedImageTypeError(Exception):
@@ -168,7 +162,7 @@ class PdfImageBase(ABC):
 
         if self.colorspace in ('/DeviceGray', '/CalGray'):
             return (0.0, 1.0)
-        if self.colorspace == ('/DeviceRGB', '/CalRGB'):
+        if self.colorspace in ('/DeviceRGB', '/CalRGB'):
             return (0.0, 1.0, 0.0, 1.0, 0.0, 1.0)
         if self.colorspace == '/DeviceCMYK':
             return (0.0, 1.0, 0.0, 1.0, 0.0, 1.0, 0.0, 1.0)
@@ -177,6 +171,8 @@ class PdfImageBase(ABC):
                 return (0.0, 1.0)
             if self._approx_mode_from_icc() == 'RGB':
                 return (0.0, 1.0, 0.0, 1.0, 0.0, 1.0)
+        if self.image_mask:
+            return (0.0, 1.0)  # Default for image masks; per RM 8.9.6.2
 
         raise NotImplementedError(
             "Don't how to retrieve default /Decode array for image" + repr(self)
@@ -202,6 +198,8 @@ class PdfImageBase(ABC):
                 if isinstance(subspace, list) and subspace[0] in (
                     '/ICCBased',
                     '/DeviceN',
+                    '/CalGray',
+                    '/CalRGB',
                 ):
                     return subspace[0]
             if self._colorspaces[0] == '/DeviceN':
@@ -329,16 +327,16 @@ class PdfImageBase(ABC):
             _idx, base, _hival, lookup = self._colorspaces
         except ValueError as e:
             raise ValueError('Not sure how to interpret this palette') from e
-        if self.icc or self.is_device_n or self.is_separation:
+        if self.icc or self.is_device_n or self.is_separation or isinstance(base, list):
             base = str(base[0])
         else:
             base = str(base)
         lookup = bytes(lookup)
         if base not in self.MAIN_COLORSPACES and base not in self.PRINT_COLORSPACES:
             raise NotImplementedError(f"not sure how to interpret this palette: {base}")
-        if base == '/DeviceRGB':
+        if base in ('/DeviceRGB', '/CalRGB'):
             base = 'RGB'
-        elif base == '/DeviceGray':
+        elif base in ('/DeviceGray', '/CalGray'):
             base = 'L'
         elif base == '/DeviceCMYK':
             base = 'CMYK'
@@ -348,6 +346,8 @@ class PdfImageBase(ABC):
             base = 'Separation'
         elif base == '/ICCBased':
             base = self._approx_mode_from_icc()
+        else:
+            raise NotImplementedError(f"not sure how to interpret this palette: {base}")
         return PaletteData(base, lookup)
 
     @abstractmethod
@@ -755,7 +755,6 @@ class PdfImage(PdfImageBase):
 
         expected_defaults = [
             ("/EncodedByteAlign", False),
-            ("/EndOfLine", False),
         ]
         for name, val in expected_defaults:
             if self.decode_parms[0].get(name, val) != val:
@@ -1050,3 +1049,19 @@ class PdfInlineImage(PdfImageBase):
         """Return decompressed stream buffer."""
         # qpdf does not have an API to return this directly, so convert it.
         return self._convert_to_pdfimage().get_stream_buffer()
+
+
+__all__ = [
+    'CMYKDecodeArray',
+    'DecodeArray',
+    'HifiPrintImageNotTranscodableError',
+    'ImageDecompressionError',
+    'InvalidPdfImageError',
+    'PaletteData',
+    'PdfImage',
+    'PdfImageBase',
+    'PdfInlineImage',
+    'PdfJpxImage',
+    'RGBDecodeArray',
+    'UnsupportedImageTypeError',
+]
